"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeDepsCmd = void 0;
const logger_1 = __importDefault(require("./logger"));
const package_url_1 = require("../domain/package-url");
const package_reference_1 = require("../domain/package-reference");
const packument_resolving_1 = require("../packument-resolving");
const common_errors_1 = require("../common-errors");
const ts_results_es_1 = require("ts-results-es");
function errorPrefixForError(error) {
    if (error instanceof common_errors_1.PackumentNotFoundError)
        return "missing dependency";
    else if (error instanceof packument_resolving_1.VersionNotFoundError)
        return "missing dependency version";
    return "unknown";
}
/**
 * Makes a {@link DepsCmd} function.
 */
function makeDepsCmd(parseEnv, resolveDependencies) {
    return async (pkg, options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr())
            return envResult;
        const env = envResult.value;
        const [name, version] = (0, package_reference_1.splitPackageReference)(pkg);
        if (version !== undefined && (0, package_url_1.isPackageUrl)(version))
            // TODO: Convert to result
            throw new Error("Cannot get dependencies for url-version");
        const deep = options.deep || false;
        logger_1.default.verbose("dependency", `fetch: ${(0, package_reference_1.makePackageReference)(name, version)}, deep=${deep}`);
        const [depsValid, depsInvalid] = await resolveDependencies(env.registry, env.upstreamRegistry, name, version, deep);
        depsValid
            .filter((x) => !x.self)
            .forEach((x) => logger_1.default.notice("dependency", `${(0, package_reference_1.makePackageReference)(x.name, x.version)}`));
        depsInvalid
            .filter((x) => !x.self)
            .forEach((x) => {
            const prefix = errorPrefixForError(x.reason);
            logger_1.default.warn(prefix, x.name);
        });
        return (0, ts_results_es_1.Ok)(undefined);
    };
}
exports.makeDepsCmd = makeDepsCmd;
//# sourceMappingURL=cmd-deps.js.map