"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeLoginCmd = void 0;
const logger_1 = __importDefault(require("./logger"));
const upm_config_io_1 = require("../io/upm-config-io");
const upm_config_1 = require("../domain/upm-config");
const registry_url_1 = require("../domain/registry-url");
const prompts_1 = require("./prompts");
const ts_results_es_1 = require("ts-results-es");
/**
 * Makes a {@link LoginCmd} function.
 */
function makeLoginCmd(parseEnv, authNpmrc, addUser) {
    return async (options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr())
            return envResult;
        const env = envResult.value;
        // query parameters
        const username = options.username ?? (await (0, prompts_1.promptUsername)());
        const password = options.password ?? (await (0, prompts_1.promptPassword)());
        const email = options.email ?? (await (0, prompts_1.promptEmail)());
        const loginRegistry = options._global.registry !== undefined
            ? (0, registry_url_1.coerceRegistryUrl)(options._global.registry)
            : await (0, prompts_1.promptRegistryUrl)();
        const alwaysAuth = options.alwaysAuth || false;
        const configDirResult = await (0, upm_config_io_1.tryGetUpmConfigDir)(env.wsl, env.systemUser)
            .promise;
        if (configDirResult.isErr())
            return configDirResult;
        const configDir = configDirResult.value;
        if (options.basicAuth) {
            // basic auth
            const _auth = (0, upm_config_1.encodeBasicAuth)(username, password);
            const result = await (0, upm_config_io_1.tryStoreUpmAuth)(configDir, loginRegistry, {
                email,
                alwaysAuth,
                _auth,
            }).promise;
            if (result.isErr())
                return result;
        }
        else {
            // npm login
            const loginResult = await addUser(loginRegistry, username, password, email).promise;
            if (loginResult.isErr()) {
                if (loginResult.error.status === 401)
                    logger_1.default.warn("401", "Incorrect username or password");
                else
                    logger_1.default.error(loginResult.error.status.toString(), loginResult.error.message);
                return loginResult;
            }
            logger_1.default.notice("auth", `you are authenticated as '${username}'`);
            const token = loginResult.value;
            // write npm token
            const updateResult = await authNpmrc(loginRegistry, token).promise;
            if (updateResult.isErr())
                return updateResult;
            updateResult.map((configPath) => logger_1.default.notice("config", `saved to npm config: ${configPath}`));
            const storeResult = await (0, upm_config_io_1.tryStoreUpmAuth)(configDir, loginRegistry, {
                email,
                alwaysAuth,
                token,
            }).promise;
            if (storeResult.isErr())
                return storeResult;
        }
        return (0, ts_results_es_1.Ok)(undefined);
    };
}
exports.makeLoginCmd = makeLoginCmd;
//# sourceMappingURL=cmd-login.js.map