"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logManifestSaveError = exports.logManifestLoadError = void 0;
const logger_1 = __importDefault(require("./logger"));
const file_io_1 = require("../io/file-io");
/**
 * Logs a {@link ManifestLoadError} to the console.
 * @param error The error to log.
 */
function logManifestLoadError(error) {
    const prefix = "manifest";
    if (error instanceof file_io_1.NotFoundError)
        logger_1.default.error(prefix, `manifest at ${error.path} does not exist`);
    else {
        logger_1.default.error(prefix, `failed to parse manifest at ${error.path}`);
        if (error.cause !== undefined)
            logger_1.default.error(prefix, error.cause.message);
    }
}
exports.logManifestLoadError = logManifestLoadError;
/**
 * Logs a {@link ManifestWriteError} to the console.
 * @param error The error to log.
 */
function logManifestSaveError(error) {
    const prefix = "manifest";
    logger_1.default.error(prefix, "can not write manifest json file");
    logger_1.default.error(prefix, error.message);
}
exports.logManifestSaveError = logManifestSaveError;
//# sourceMappingURL=error-logging.js.map