"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeDomainName = exports.isInternalPackage = exports.isDomainName = void 0;
const assert_1 = __importDefault(require("assert"));
const segmentRegex = /^(?!.*--|^-.*|.*-$)[a-zA-Z0-9-]+$/;
function domainSegmentsIn(hostName) {
    return hostName.split(".");
}
/**
 * Checks if a string is a domain name. Only does basic syntax validation.
 * Does not check for correct segment-count etc.
 * @param s The string.
 */
function isDomainName(s) {
    const segments = domainSegmentsIn(s);
    if (segments.length === 0)
        return false;
    return segments.every((segment) => segmentRegex.test(segment));
}
exports.isDomainName = isDomainName;
/**
 * Detect if the given package name is an internal package.
 * @param name The name of the package.
 */
const isInternalPackage = (name) => {
    const internals = [
        "com.unity.ugui",
        "com.unity.2d.sprite",
        "com.unity.2d.tilemap",
        "com.unity.package-manager-ui",
        "com.unity.ugui",
    ];
    return /com.unity.modules/i.test(name) || internals.includes(name);
};
exports.isInternalPackage = isInternalPackage;
/**
 * Constructs a domain-name from a string.
 * @param s The string.
 * @throws {assert.AssertionError} If string is not in valid format.
 */
function makeDomainName(s) {
    (0, assert_1.default)(isDomainName(s), `"${s}" is a domain name`);
    return s;
}
exports.makeDomainName = makeDomainName;
//# sourceMappingURL=domain-name.js.map