"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setToken = exports.emptyNpmrc = void 0;
/**
 * An empty npmrc (No lines).
 */
exports.emptyNpmrc = [];
/**
 * Adds or updates the auth-token for a registry.
 * @param npmrc The current npmrc.
 * @param registry The registry to set the token for.
 * @param token The token.
 */
function setToken(npmrc, registry, token) {
    let lines = [...npmrc];
    const quotes = /[?=]/.test(token) ? '"' : "";
    // get the registry url without http protocol
    let registryUrl = registry.slice(registry.search(/:\/\//) + 1);
    // add trailing slash
    if (!registryUrl.endsWith("/"))
        registryUrl = registryUrl + "/";
    const index = lines.findIndex(function (element, index) {
        if (element.indexOf(registryUrl + ":_authToken=") !== -1) {
            // If an entry for the auth token is found, replace it
            lines[index] = element.replace(/authToken=.*/, "authToken=" + quotes + token + quotes);
            return true;
        }
        return false;
    });
    // If no entry for the auth token is found, add one
    if (index === -1) {
        lines.push(registryUrl + ":_authToken=" + quotes + token + quotes);
    }
    // Remove empty lines
    lines = lines.filter((l) => l);
    return lines;
}
exports.setToken = setToken;
//# sourceMappingURL=npmrc.js.map