"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryGetTargetEditorVersionFor = exports.InvalidTargetEditorError = exports.tryGetLatestVersion = void 0;
const ts_results_es_1 = require("ts-results-es");
const editor_version_1 = require("./editor-version");
const ts_custom_error_1 = require("ts-custom-error");
const hasLatestDistTag = (packument) => {
    return packument["dist-tags"]?.["latest"] !== undefined;
};
/**
 * Attempt to get the latest version from a package.
 * @param packument The package. All properties are assumed to be potentially
 * missing.
 */
const tryGetLatestVersion = function (packument) {
    if (hasLatestDistTag(packument))
        return packument["dist-tags"].latest;
    else if (packument.version)
        return packument.version;
};
exports.tryGetLatestVersion = tryGetLatestVersion;
/**
 * Error for when a packument contained an invalid target editor-version.
 */
class InvalidTargetEditorError extends ts_custom_error_1.CustomError {
    constructor(
    /**
     * The invalid editor-version string.
     */
    versionString) {
        super();
        this.versionString = versionString;
        // noinspection JSUnusedLocalSymbols
        this._class = "InvalidTargetEditorError";
    }
}
exports.InvalidTargetEditorError = InvalidTargetEditorError;
/**
 * Extracts the target editor-version from a packument-version.
 * @param packumentVersion The packument-version for which to get the editor.
 * @returns The editor-version or null if the packument is compatible
 * with all Unity version.
 */
function tryGetTargetEditorVersionFor(packumentVersion) {
    if (packumentVersion.unity === undefined)
        return (0, ts_results_es_1.Ok)(null);
    const majorMinor = packumentVersion.unity;
    const release = packumentVersion.unityRelease !== undefined
        ? `.${packumentVersion.unityRelease}`
        : "";
    const versionString = `${majorMinor}${release}`;
    const parsed = (0, editor_version_1.tryParseEditorVersion)(versionString);
    return parsed !== null
        ? (0, ts_results_es_1.Ok)(parsed)
        : (0, ts_results_es_1.Err)(new InvalidTargetEditorError(versionString));
}
exports.tryGetTargetEditorVersionFor = tryGetTargetEditorVersionFor;
//# sourceMappingURL=packument.js.map