"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.trySaveNpmrc = exports.tryLoadNpmrc = exports.tryGetNpmrcPath = void 0;
const ts_results_es_1 = require("ts-results-es");
const file_io_1 = require("./file-io");
const node_os_1 = require("node:os");
const path_1 = __importDefault(require("path"));
const special_paths_1 = require("./special-paths");
/**
 * Tries to get the npmrc path based on env.
 */
function tryGetNpmrcPath() {
    return (0, special_paths_1.tryGetHomePath)().map((homePath) => path_1.default.join(homePath, ".npmrc"));
}
exports.tryGetNpmrcPath = tryGetNpmrcPath;
/**
 * Attempts to load an .npmrc. It will load all lines from the file.
 * @param path The path to load from.
 */
function tryLoadNpmrc(path) {
    return (0, file_io_1.tryReadTextFromFile)(path)
        .map((content) => content.split(node_os_1.EOL))
        .orElse((error) => error instanceof file_io_1.NotFoundError ? (0, ts_results_es_1.Ok)(null) : (0, ts_results_es_1.Err)(error));
}
exports.tryLoadNpmrc = tryLoadNpmrc;
/**
 * Attempts to save a npmrc. Overwrites the content of the file.
 * @param path The path to the file.
 * @param npmrc The new lines for the file.
 */
function trySaveNpmrc(path, npmrc) {
    const content = npmrc.join(node_os_1.EOL);
    return (0, file_io_1.tryWriteTextToFile)(path, content);
}
exports.trySaveNpmrc = trySaveNpmrc;
//# sourceMappingURL=npmrc-io.js.map