"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeAddUserService = exports.AuthenticationError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
const ts_results_es_1 = require("ts-results-es");
/**
 * Error for when authentication failed.
 */
class AuthenticationError extends ts_custom_error_1.CustomError {
    constructor(
    /**
     * The http-response code returned by the server.
     */
    status, message) {
        super(message);
        this.status = status;
        this._class = "AuthenticationError";
    }
}
exports.AuthenticationError = AuthenticationError;
/**
 * Makes a new {@link AddUserService} function.
 */
function makeAddUserService(registryClient) {
    return (registryUrl, username, email, password) => {
        return new ts_results_es_1.AsyncResult(new Promise((resolve) => {
            registryClient.adduser(registryUrl, { auth: { username, email, password } }, (error, responseData, _, response) => {
                if (error !== null || !responseData.ok)
                    resolve((0, ts_results_es_1.Err)(new AuthenticationError(response.statusCode, response.statusMessage)));
                else
                    resolve((0, ts_results_es_1.Ok)(responseData.token));
            });
        }));
    };
}
exports.makeAddUserService = makeAddUserService;
//# sourceMappingURL=add-user.js.map