"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeFetchPackumentService = void 0;
const ts_results_es_1 = require("ts-results-es");
const error_type_guards_1 = require("../utils/error-type-guards");
/**
 * Makes a {@link FetchPackumentService} function.
 */
function makeFetchPackumentService(registryClient) {
    return (registry, name) => {
        const url = `${registry.url}/${name}`;
        return new ts_results_es_1.AsyncResult(new Promise((resolve) => {
            return registryClient.get(url, { auth: registry.auth || undefined }, (error, packument) => {
                if (error !== null) {
                    (0, error_type_guards_1.assertIsHttpError)(error);
                    if (error.statusCode === 404)
                        resolve((0, ts_results_es_1.Ok)(null));
                    else
                        resolve((0, ts_results_es_1.Err)(error));
                }
                else
                    resolve((0, ts_results_es_1.Ok)(packument));
            });
        }));
    };
}
exports.makeFetchPackumentService = makeFetchPackumentService;
//# sourceMappingURL=fetch-packument.js.map