"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeGetBuiltInPackagesService = exports.EditorNotInstalledError = void 0;
const special_paths_1 = require("../io/special-paths");
const ts_custom_error_1 = require("ts-custom-error");
const path_1 = __importDefault(require("path"));
const file_io_1 = require("../io/file-io");
/**
 * Error for when an editor-version is not installed.
 */
class EditorNotInstalledError extends ts_custom_error_1.CustomError {
    constructor(
    /**
     * The version that is not installed.
     */
    version) {
        super();
        this.version = version;
        this._class = "EditorNotInstalledError";
    }
}
exports.EditorNotInstalledError = EditorNotInstalledError;
/**
 * Makes a {@link GetBuiltInPackagesService} function.
 */
function makeGetBuiltInPackagesService() {
    return (editorVersion) => {
        {
            const pathResult = (0, special_paths_1.tryGetEditorInstallPath)(editorVersion);
            if (pathResult.isErr())
                return pathResult.toAsyncResult();
            const installPath = pathResult.value;
            const packagesDir = path_1.default.join(installPath, "Editor/Data/Resources/PackageManager/BuiltInPackages");
            return ((0, file_io_1.tryGetDirectoriesIn)(packagesDir)
                // We can assume correct format
                .map((names) => names)
                .mapErr((error) => error instanceof file_io_1.NotFoundError
                ? new EditorNotInstalledError(editorVersion)
                : error));
        }
    };
}
exports.makeGetBuiltInPackagesService = makeGetBuiltInPackagesService;
//# sourceMappingURL=get-builtin-packages.js.map