"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeResolveRemotePackumentService = void 0;
const ts_results_es_1 = require("ts-results-es");
const packument_resolving_1 = require("../packument-resolving");
const common_errors_1 = require("../common-errors");
/**
 * Makes a {@link ResolveRemotePackumentService} function.
 */
function makeResolveRemotePackumentService(fetchPackument) {
    return (packageName, requestedVersion, source) => fetchPackument(source, packageName)
        .andThen((maybePackument) => {
        if (maybePackument === null)
            return (0, ts_results_es_1.Err)(new common_errors_1.PackumentNotFoundError());
        return (0, ts_results_es_1.Ok)(maybePackument);
    })
        .andThen((packument) => (0, packument_resolving_1.tryResolveFromPackument)(packument, requestedVersion, source.url));
}
exports.makeResolveRemotePackumentService = makeResolveRemotePackumentService;
//# sourceMappingURL=resolve-remote-packument.js.map