"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryParseToml = exports.tryParseJson = exports.StringFormatError = void 0;
const toml_1 = __importDefault(require("@iarna/toml"));
const ts_results_es_1 = require("ts-results-es");
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Error for when a string could not be parsed to a specific format.
 */
class StringFormatError extends ts_custom_error_1.CustomError {
    constructor(formatName) {
        super();
        this.formatName = formatName;
        // noinspection JSUnusedLocalSymbols
        this._class = "StringFormatError";
    }
}
exports.StringFormatError = StringFormatError;
/**
 * Attempts to parse a json-string.
 * @param json The string to be parsed.
 */
function tryParseJson(json) {
    return ts_results_es_1.Result.wrap(() => JSON.parse(json)).mapErr(() => new StringFormatError("Json"));
}
exports.tryParseJson = tryParseJson;
/**
 * Attempts to parse a toml-string.
 * @param toml The string to be parsed.
 */
function tryParseToml(toml) {
    return ts_results_es_1.Result.wrap(() => toml_1.default.parse(toml)).mapErr(() => new StringFormatError("Toml"));
}
exports.tryParseToml = tryParseToml;
//# sourceMappingURL=data-parsing.js.map