"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChildProcessError = void 0;
const child_process_1 = __importDefault(require("child_process"));
const ts_results_es_1 = require("ts-results-es");
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Error that might occur when running a child process.
 */
class ChildProcessError extends ts_custom_error_1.CustomError {
    constructor(
    /**
     * The internal error that caused this error.
     */
    cause) {
        super();
        this.cause = cause;
        this._class = "ChildProcessError";
    }
}
exports.ChildProcessError = ChildProcessError;
/**
 * @param command A shell command to execute.
 * @param trim Whether to trim whitespace from command output.
 * @returns Result with either stdout string or an error.
 */
function execute(command, { trim }) {
    return new ts_results_es_1.AsyncResult(new Promise(function (resolve) {
        child_process_1.default.exec(command, function (error, stdout, stderr) {
            if (error) {
                resolve((0, ts_results_es_1.Err)(new ChildProcessError(error)));
                return;
            }
            if (stderr) {
                resolve((0, ts_results_es_1.Err)(new ChildProcessError(new Error(stderr))));
                return;
            }
            resolve((0, ts_results_es_1.Ok)(trim ? stdout.trim() : stdout));
        });
    }));
}
exports.default = execute;
//# sourceMappingURL=process.js.map